#[non_exhaustive]pub struct CreateGeofenceCollectionInput {
pub collection_name: Option<String>,
pub pricing_plan: Option<PricingPlan>,
pub pricing_plan_data_source: Option<String>,
pub description: Option<String>,
pub tags: Option<HashMap<String, String>>,
pub kms_key_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.collection_name: Option<String>A custom name for the geofence collection.
Requirements:
-
Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).
-
Must be a unique geofence collection name.
-
No spaces allowed. For example,
ExampleGeofenceCollection.
pricing_plan: Option<PricingPlan>Deprecated. If included, the only allowed value is RequestBasedUsage.
No longer used. If included, the only allowed value is RequestBasedUsage.
pricing_plan_data_source: Option<String>Deprecated. No longer allowed.
This parameter is no longer used.
description: Option<String>An optional description for the geofence collection.
Applies one or more tags to the geofence collection. A tag is a key-value pair helps manage, identify, search, and filter your resources by labelling them.
Format: "key" : "value"
Restrictions:
-
Maximum 50 tags per resource
-
Each resource tag must be unique with a maximum of one value.
-
Maximum key length: 128 Unicode characters in UTF-8
-
Maximum value length: 256 Unicode characters in UTF-8
-
Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.
-
Cannot use "aws:" as a prefix for a key.
kms_key_id: Option<String>A key identifier for an Amazon Web Services KMS customer managed key. Enter a key ID, key ARN, alias name, or alias ARN.
Implementations
Sourceimpl CreateGeofenceCollectionInput
impl CreateGeofenceCollectionInput
Sourcepub fn collection_name(&self) -> Option<&str>
pub fn collection_name(&self) -> Option<&str>
A custom name for the geofence collection.
Requirements:
-
Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).
-
Must be a unique geofence collection name.
-
No spaces allowed. For example,
ExampleGeofenceCollection.
Sourcepub fn pricing_plan(&self) -> Option<&PricingPlan>
👎Deprecated since 2022-02-01: Deprecated. If included, the only allowed value is RequestBasedUsage.
pub fn pricing_plan(&self) -> Option<&PricingPlan>
Deprecated. If included, the only allowed value is RequestBasedUsage.
No longer used. If included, the only allowed value is RequestBasedUsage.
Sourcepub fn pricing_plan_data_source(&self) -> Option<&str>
👎Deprecated since 2022-02-01: Deprecated. No longer allowed.
pub fn pricing_plan_data_source(&self) -> Option<&str>
Deprecated. No longer allowed.
This parameter is no longer used.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
An optional description for the geofence collection.
Applies one or more tags to the geofence collection. A tag is a key-value pair helps manage, identify, search, and filter your resources by labelling them.
Format: "key" : "value"
Restrictions:
-
Maximum 50 tags per resource
-
Each resource tag must be unique with a maximum of one value.
-
Maximum key length: 128 Unicode characters in UTF-8
-
Maximum value length: 256 Unicode characters in UTF-8
-
Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.
-
Cannot use "aws:" as a prefix for a key.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
A key identifier for an Amazon Web Services KMS customer managed key. Enter a key ID, key ARN, alias name, or alias ARN.
Sourceimpl CreateGeofenceCollectionInput
impl CreateGeofenceCollectionInput
Sourcepub fn builder() -> CreateGeofenceCollectionInputBuilder
pub fn builder() -> CreateGeofenceCollectionInputBuilder
Creates a new builder-style object to manufacture CreateGeofenceCollectionInput.