#[non_exhaustive]pub struct CreateKeyInputBuilder { /* private fields */ }Expand description
A builder for CreateKeyInput.
Implementations
Sourceimpl CreateKeyInputBuilder
impl CreateKeyInputBuilder
Sourcepub fn key_name(self, input: impl Into<String>) -> Self
pub fn key_name(self, input: impl Into<String>) -> Self
A custom name for the API key resource.
Requirements:
-
Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).
-
Must be a unique API key name.
-
No spaces allowed. For example,
ExampleAPIKey.
Sourcepub fn set_key_name(self, input: Option<String>) -> Self
pub fn set_key_name(self, input: Option<String>) -> Self
A custom name for the API key resource.
Requirements:
-
Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).
-
Must be a unique API key name.
-
No spaces allowed. For example,
ExampleAPIKey.
Sourcepub fn get_key_name(&self) -> &Option<String>
pub fn get_key_name(&self) -> &Option<String>
A custom name for the API key resource.
Requirements:
-
Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).
-
Must be a unique API key name.
-
No spaces allowed. For example,
ExampleAPIKey.
Sourcepub fn restrictions(self, input: ApiKeyRestrictions) -> Self
pub fn restrictions(self, input: ApiKeyRestrictions) -> Self
The API key restrictions for the API key resource.
This field is required.Sourcepub fn set_restrictions(self, input: Option<ApiKeyRestrictions>) -> Self
pub fn set_restrictions(self, input: Option<ApiKeyRestrictions>) -> Self
The API key restrictions for the API key resource.
Sourcepub fn get_restrictions(&self) -> &Option<ApiKeyRestrictions>
pub fn get_restrictions(&self) -> &Option<ApiKeyRestrictions>
The API key restrictions for the API key resource.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
An optional description for the API key resource.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
An optional description for the API key resource.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
An optional description for the API key resource.
Sourcepub fn expire_time(self, input: DateTime) -> Self
pub fn expire_time(self, input: DateTime) -> Self
The optional timestamp for when the API key resource will expire in ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ. One of NoExpiry or ExpireTime must be set.
Sourcepub fn set_expire_time(self, input: Option<DateTime>) -> Self
pub fn set_expire_time(self, input: Option<DateTime>) -> Self
The optional timestamp for when the API key resource will expire in ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ. One of NoExpiry or ExpireTime must be set.
Sourcepub fn get_expire_time(&self) -> &Option<DateTime>
pub fn get_expire_time(&self) -> &Option<DateTime>
The optional timestamp for when the API key resource will expire in ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ. One of NoExpiry or ExpireTime must be set.
Sourcepub fn no_expiry(self, input: bool) -> Self
pub fn no_expiry(self, input: bool) -> Self
Optionally set to true to set no expiration time for the API key. One of NoExpiry or ExpireTime must be set.
Sourcepub fn set_no_expiry(self, input: Option<bool>) -> Self
pub fn set_no_expiry(self, input: Option<bool>) -> Self
Optionally set to true to set no expiration time for the API key. One of NoExpiry or ExpireTime must be set.
Sourcepub fn get_no_expiry(&self) -> &Option<bool>
pub fn get_no_expiry(&self) -> &Option<bool>
Optionally set to true to set no expiration time for the API key. One of NoExpiry or ExpireTime must be set.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Applies one or more tags to the map resource. A tag is a key-value pair that helps manage, identify, search, and filter your resources by labelling them.
Format: "key" : "value"
Restrictions:
-
Maximum 50 tags per resource
-
Each resource tag must be unique with a maximum of one value.
-
Maximum key length: 128 Unicode characters in UTF-8
-
Maximum value length: 256 Unicode characters in UTF-8
-
Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.
-
Cannot use "aws:" as a prefix for a key.
Applies one or more tags to the map resource. A tag is a key-value pair that helps manage, identify, search, and filter your resources by labelling them.
Format: "key" : "value"
Restrictions:
-
Maximum 50 tags per resource
-
Each resource tag must be unique with a maximum of one value.
-
Maximum key length: 128 Unicode characters in UTF-8
-
Maximum value length: 256 Unicode characters in UTF-8
-
Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.
-
Cannot use "aws:" as a prefix for a key.
Applies one or more tags to the map resource. A tag is a key-value pair that helps manage, identify, search, and filter your resources by labelling them.
Format: "key" : "value"
Restrictions:
-
Maximum 50 tags per resource
-
Each resource tag must be unique with a maximum of one value.
-
Maximum key length: 128 Unicode characters in UTF-8
-
Maximum value length: 256 Unicode characters in UTF-8
-
Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.
-
Cannot use "aws:" as a prefix for a key.
Sourcepub fn build(self) -> Result<CreateKeyInput, BuildError>
pub fn build(self) -> Result<CreateKeyInput, BuildError>
Consumes the builder and constructs a CreateKeyInput.
Sourceimpl CreateKeyInputBuilder
impl CreateKeyInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateKeyOutput, SdkError<CreateKeyError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateKeyOutput, SdkError<CreateKeyError, HttpResponse>>
Sends a request with this input using the given client.