#[non_exhaustive]pub struct CreateKeyInput {
pub key_name: Option<String>,
pub restrictions: Option<ApiKeyRestrictions>,
pub description: Option<String>,
pub expire_time: Option<DateTime>,
pub no_expiry: Option<bool>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key_name: Option<String>A custom name for the API key resource.
Requirements:
-
Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).
-
Must be a unique API key name.
-
No spaces allowed. For example,
ExampleAPIKey.
restrictions: Option<ApiKeyRestrictions>The API key restrictions for the API key resource.
description: Option<String>An optional description for the API key resource.
expire_time: Option<DateTime>The optional timestamp for when the API key resource will expire in ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ. One of NoExpiry or ExpireTime must be set.
no_expiry: Option<bool>Optionally set to true to set no expiration time for the API key. One of NoExpiry or ExpireTime must be set.
Applies one or more tags to the map resource. A tag is a key-value pair that helps manage, identify, search, and filter your resources by labelling them.
Format: "key" : "value"
Restrictions:
-
Maximum 50 tags per resource
-
Each resource tag must be unique with a maximum of one value.
-
Maximum key length: 128 Unicode characters in UTF-8
-
Maximum value length: 256 Unicode characters in UTF-8
-
Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.
-
Cannot use "aws:" as a prefix for a key.
Implementations
Sourceimpl CreateKeyInput
impl CreateKeyInput
Sourcepub fn key_name(&self) -> Option<&str>
pub fn key_name(&self) -> Option<&str>
A custom name for the API key resource.
Requirements:
-
Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).
-
Must be a unique API key name.
-
No spaces allowed. For example,
ExampleAPIKey.
Sourcepub fn restrictions(&self) -> Option<&ApiKeyRestrictions>
pub fn restrictions(&self) -> Option<&ApiKeyRestrictions>
The API key restrictions for the API key resource.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
An optional description for the API key resource.
Sourcepub fn expire_time(&self) -> Option<&DateTime>
pub fn expire_time(&self) -> Option<&DateTime>
The optional timestamp for when the API key resource will expire in ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ. One of NoExpiry or ExpireTime must be set.
Sourcepub fn no_expiry(&self) -> Option<bool>
pub fn no_expiry(&self) -> Option<bool>
Optionally set to true to set no expiration time for the API key. One of NoExpiry or ExpireTime must be set.
Applies one or more tags to the map resource. A tag is a key-value pair that helps manage, identify, search, and filter your resources by labelling them.
Format: "key" : "value"
Restrictions:
-
Maximum 50 tags per resource
-
Each resource tag must be unique with a maximum of one value.
-
Maximum key length: 128 Unicode characters in UTF-8
-
Maximum value length: 256 Unicode characters in UTF-8
-
Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.
-
Cannot use "aws:" as a prefix for a key.
Sourceimpl CreateKeyInput
impl CreateKeyInput
Sourcepub fn builder() -> CreateKeyInputBuilder
pub fn builder() -> CreateKeyInputBuilder
Creates a new builder-style object to manufacture CreateKeyInput.