#[non_exhaustive]pub struct DeleteKeyInput {
pub key_name: Option<String>,
pub force_delete: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key_name: Option<String>The name of the API key to delete.
force_delete: Option<bool>ForceDelete bypasses an API key's expiry conditions and deletes the key. Set the parameter true to delete the key or to false to not preemptively delete the API key.
Valid values: true, or false.
Required: No
This action is irreversible. Only use ForceDelete if you are certain the key is no longer in use.
Implementations
Sourceimpl DeleteKeyInput
impl DeleteKeyInput
Sourcepub fn force_delete(&self) -> Option<bool>
pub fn force_delete(&self) -> Option<bool>
ForceDelete bypasses an API key's expiry conditions and deletes the key. Set the parameter true to delete the key or to false to not preemptively delete the API key.
Valid values: true, or false.
Required: No
This action is irreversible. Only use ForceDelete if you are certain the key is no longer in use.
Sourceimpl DeleteKeyInput
impl DeleteKeyInput
Sourcepub fn builder() -> DeleteKeyInputBuilder
pub fn builder() -> DeleteKeyInputBuilder
Creates a new builder-style object to manufacture DeleteKeyInput.