#[non_exhaustive]pub struct ListMapsInput {
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_results: Option<i32>An optional limit for the number of resources returned in a single call.
Default value: 100
next_token: Option<String>The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.
Default value: null
Implementations
Sourceimpl ListMapsInput
impl ListMapsInput
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
An optional limit for the number of resources returned in a single call.
Default value: 100
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.
Default value: null
Sourceimpl ListMapsInput
impl ListMapsInput
Sourcepub fn builder() -> ListMapsInputBuilder
pub fn builder() -> ListMapsInputBuilder
Creates a new builder-style object to manufacture ListMapsInput.