#[non_exhaustive]pub struct VerifyDevicePositionInput {
pub tracker_name: Option<String>,
pub device_state: Option<DeviceState>,
pub distance_unit: Option<DistanceUnit>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tracker_name: Option<String>The name of the tracker resource to be associated with verification request.
device_state: Option<DeviceState>The device's state, including position, IP address, cell signals and Wi-Fi access points.
distance_unit: Option<DistanceUnit>The distance unit for the verification request.
Default Value: Kilometers
Implementations
Sourceimpl VerifyDevicePositionInput
impl VerifyDevicePositionInput
Sourcepub fn tracker_name(&self) -> Option<&str>
pub fn tracker_name(&self) -> Option<&str>
The name of the tracker resource to be associated with verification request.
Sourcepub fn device_state(&self) -> Option<&DeviceState>
pub fn device_state(&self) -> Option<&DeviceState>
The device's state, including position, IP address, cell signals and Wi-Fi access points.
Sourcepub fn distance_unit(&self) -> Option<&DistanceUnit>
pub fn distance_unit(&self) -> Option<&DistanceUnit>
The distance unit for the verification request.
Default Value: Kilometers
Sourceimpl VerifyDevicePositionInput
impl VerifyDevicePositionInput
Sourcepub fn builder() -> VerifyDevicePositionInputBuilder
pub fn builder() -> VerifyDevicePositionInputBuilder
Creates a new builder-style object to manufacture VerifyDevicePositionInput.