#[non_exhaustive]pub struct AndroidAppBuilder { /* private fields */ }Expand description
A builder for AndroidApp.
Implementations
Sourceimpl AndroidAppBuilder
impl AndroidAppBuilder
Sourcepub fn package(self, input: impl Into<String>) -> Self
pub fn package(self, input: impl Into<String>) -> Self
Unique package name identifier for an Android app.
Example: com.mydomain.appname
Sourcepub fn set_package(self, input: Option<String>) -> Self
pub fn set_package(self, input: Option<String>) -> Self
Unique package name identifier for an Android app.
Example: com.mydomain.appname
Sourcepub fn get_package(&self) -> &Option<String>
pub fn get_package(&self) -> &Option<String>
Unique package name identifier for an Android app.
Example: com.mydomain.appname
Sourcepub fn certificate_fingerprint(self, input: impl Into<String>) -> Self
pub fn certificate_fingerprint(self, input: impl Into<String>) -> Self
20 byte SHA-1 certificate fingerprint associated with the Android app signing certificate.
Example: BB:0D:AC:74:D3:21:E1:43:67:71:9B:62:91:AF:A1:66:6E:44:5D:75
Sourcepub fn set_certificate_fingerprint(self, input: Option<String>) -> Self
pub fn set_certificate_fingerprint(self, input: Option<String>) -> Self
20 byte SHA-1 certificate fingerprint associated with the Android app signing certificate.
Example: BB:0D:AC:74:D3:21:E1:43:67:71:9B:62:91:AF:A1:66:6E:44:5D:75
Sourcepub fn get_certificate_fingerprint(&self) -> &Option<String>
pub fn get_certificate_fingerprint(&self) -> &Option<String>
20 byte SHA-1 certificate fingerprint associated with the Android app signing certificate.
Example: BB:0D:AC:74:D3:21:E1:43:67:71:9B:62:91:AF:A1:66:6E:44:5D:75
Sourcepub fn build(self) -> Result<AndroidApp, BuildError>
pub fn build(self) -> Result<AndroidApp, BuildError>
Consumes the builder and constructs a AndroidApp.
This method will fail if any of the following fields are not set: