#[non_exhaustive]pub struct DeviceStateBuilder { /* private fields */ }Expand description
A builder for DeviceState.
Implementations
Sourceimpl DeviceStateBuilder
impl DeviceStateBuilder
Sourcepub fn device_id(self, input: impl Into<String>) -> Self
pub fn device_id(self, input: impl Into<String>) -> Self
The device identifier.
This field is required.Sourcepub fn set_device_id(self, input: Option<String>) -> Self
pub fn set_device_id(self, input: Option<String>) -> Self
The device identifier.
Sourcepub fn get_device_id(&self) -> &Option<String>
pub fn get_device_id(&self) -> &Option<String>
The device identifier.
Sourcepub fn sample_time(self, input: DateTime) -> Self
pub fn sample_time(self, input: DateTime) -> Self
The timestamp at which the device's position was determined. Uses ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ.
Sourcepub fn set_sample_time(self, input: Option<DateTime>) -> Self
pub fn set_sample_time(self, input: Option<DateTime>) -> Self
The timestamp at which the device's position was determined. Uses ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ.
Sourcepub fn get_sample_time(&self) -> &Option<DateTime>
pub fn get_sample_time(&self) -> &Option<DateTime>
The timestamp at which the device's position was determined. Uses ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ.
Sourcepub fn position(self, input: f64) -> Self
pub fn position(self, input: f64) -> Self
Appends an item to position.
To override the contents of this collection use set_position.
The last known device position.
Sourcepub fn set_position(self, input: Option<Vec<f64>>) -> Self
pub fn set_position(self, input: Option<Vec<f64>>) -> Self
The last known device position.
Sourcepub fn get_position(&self) -> &Option<Vec<f64>>
pub fn get_position(&self) -> &Option<Vec<f64>>
The last known device position.
Sourcepub fn accuracy(self, input: PositionalAccuracy) -> Self
pub fn accuracy(self, input: PositionalAccuracy) -> Self
Defines the level of certainty of the position.
Sourcepub fn set_accuracy(self, input: Option<PositionalAccuracy>) -> Self
pub fn set_accuracy(self, input: Option<PositionalAccuracy>) -> Self
Defines the level of certainty of the position.
Sourcepub fn get_accuracy(&self) -> &Option<PositionalAccuracy>
pub fn get_accuracy(&self) -> &Option<PositionalAccuracy>
Defines the level of certainty of the position.
Sourcepub fn ipv4_address(self, input: impl Into<String>) -> Self
pub fn ipv4_address(self, input: impl Into<String>) -> Self
The device's Ipv4 address.
Sourcepub fn set_ipv4_address(self, input: Option<String>) -> Self
pub fn set_ipv4_address(self, input: Option<String>) -> Self
The device's Ipv4 address.
Sourcepub fn get_ipv4_address(&self) -> &Option<String>
pub fn get_ipv4_address(&self) -> &Option<String>
The device's Ipv4 address.
Sourcepub fn wi_fi_access_points(self, input: WiFiAccessPoint) -> Self
pub fn wi_fi_access_points(self, input: WiFiAccessPoint) -> Self
Appends an item to wi_fi_access_points.
To override the contents of this collection use set_wi_fi_access_points.
The Wi-Fi access points the device is using.
Sourcepub fn set_wi_fi_access_points(
self,
input: Option<Vec<WiFiAccessPoint>>,
) -> Self
pub fn set_wi_fi_access_points( self, input: Option<Vec<WiFiAccessPoint>>, ) -> Self
The Wi-Fi access points the device is using.
Sourcepub fn get_wi_fi_access_points(&self) -> &Option<Vec<WiFiAccessPoint>>
pub fn get_wi_fi_access_points(&self) -> &Option<Vec<WiFiAccessPoint>>
The Wi-Fi access points the device is using.
Sourcepub fn cell_signals(self, input: CellSignals) -> Self
pub fn cell_signals(self, input: CellSignals) -> Self
The cellular network infrastructure that the device is connected to.
Sourcepub fn set_cell_signals(self, input: Option<CellSignals>) -> Self
pub fn set_cell_signals(self, input: Option<CellSignals>) -> Self
The cellular network infrastructure that the device is connected to.
Sourcepub fn get_cell_signals(&self) -> &Option<CellSignals>
pub fn get_cell_signals(&self) -> &Option<CellSignals>
The cellular network infrastructure that the device is connected to.
Sourcepub fn build(self) -> Result<DeviceState, BuildError>
pub fn build(self) -> Result<DeviceState, BuildError>
Consumes the builder and constructs a DeviceState.
This method will fail if any of the following fields are not set: