#[non_exhaustive]pub struct AndroidApp {
pub package: String,
pub certificate_fingerprint: String,
}Expand description
Unique identifying information for an Android app. Consists of a package name and a 20 byte SHA-1 certificate fingerprint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.package: StringUnique package name identifier for an Android app.
Example: com.mydomain.appname
certificate_fingerprint: String20 byte SHA-1 certificate fingerprint associated with the Android app signing certificate.
Example: BB:0D:AC:74:D3:21:E1:43:67:71:9B:62:91:AF:A1:66:6E:44:5D:75
Implementations
Sourceimpl AndroidApp
impl AndroidApp
Sourcepub fn package(&self) -> &str
pub fn package(&self) -> &str
Unique package name identifier for an Android app.
Example: com.mydomain.appname
Sourcepub fn certificate_fingerprint(&self) -> &str
pub fn certificate_fingerprint(&self) -> &str
20 byte SHA-1 certificate fingerprint associated with the Android app signing certificate.
Example: BB:0D:AC:74:D3:21:E1:43:67:71:9B:62:91:AF:A1:66:6E:44:5D:75
Sourceimpl AndroidApp
impl AndroidApp
Sourcepub fn builder() -> AndroidAppBuilder
pub fn builder() -> AndroidAppBuilder
Creates a new builder-style object to manufacture AndroidApp.