#[non_exhaustive]pub struct Circle {
pub center: Vec<f64>,
pub radius: f64,
}Expand description
A circle on the earth, as defined by a center point and a radius.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.center: Vec<f64>A single point geometry, specifying the center of the circle, using WGS 84 coordinates, in the form \[longitude, latitude\].
radius: f64The radius of the circle in meters. Must be greater than zero and no larger than 100,000 (100 kilometers).
Implementations