#[non_exhaustive]pub struct DeviceState {
pub device_id: String,
pub sample_time: DateTime,
pub position: Vec<f64>,
pub accuracy: Option<PositionalAccuracy>,
pub ipv4_address: Option<String>,
pub wi_fi_access_points: Option<Vec<WiFiAccessPoint>>,
pub cell_signals: Option<CellSignals>,
}Expand description
The device's position, IP address, and Wi-Fi access points.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.device_id: StringThe device identifier.
sample_time: DateTimeThe timestamp at which the device's position was determined. Uses ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ.
position: Vec<f64>The last known device position.
accuracy: Option<PositionalAccuracy>Defines the level of certainty of the position.
ipv4_address: Option<String>The device's Ipv4 address.
wi_fi_access_points: Option<Vec<WiFiAccessPoint>>The Wi-Fi access points the device is using.
cell_signals: Option<CellSignals>The cellular network infrastructure that the device is connected to.
Implementations
Sourceimpl DeviceState
impl DeviceState
Sourcepub fn sample_time(&self) -> &DateTime
pub fn sample_time(&self) -> &DateTime
The timestamp at which the device's position was determined. Uses ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ.
Sourcepub fn accuracy(&self) -> Option<&PositionalAccuracy>
pub fn accuracy(&self) -> Option<&PositionalAccuracy>
Defines the level of certainty of the position.
Sourcepub fn ipv4_address(&self) -> Option<&str>
pub fn ipv4_address(&self) -> Option<&str>
The device's Ipv4 address.
Sourcepub fn wi_fi_access_points(&self) -> &[WiFiAccessPoint]
pub fn wi_fi_access_points(&self) -> &[WiFiAccessPoint]
The Wi-Fi access points the device is using.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .wi_fi_access_points.is_none().
Sourcepub fn cell_signals(&self) -> Option<&CellSignals>
pub fn cell_signals(&self) -> Option<&CellSignals>
The cellular network infrastructure that the device is connected to.
Sourceimpl DeviceState
impl DeviceState
Sourcepub fn builder() -> DeviceStateBuilder
pub fn builder() -> DeviceStateBuilder
Creates a new builder-style object to manufacture DeviceState.