#[non_exhaustive]pub struct ForecastedEvent {
pub event_id: String,
pub geofence_id: String,
pub is_device_in_geofence: bool,
pub nearest_distance: f64,
pub event_type: ForecastedGeofenceEventType,
pub forecasted_breach_time: Option<DateTime>,
pub geofence_properties: Option<HashMap<String, String>>,
}Expand description
A forecasted event represents a geofence event in relation to the requested device state, that may occur given the provided device state and time horizon.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_id: StringThe forecasted event identifier.
geofence_id: StringThe geofence identifier pertaining to the forecasted event.
is_device_in_geofence: boolIndicates if the device is located within the geofence.
nearest_distance: f64The closest distance from the device's position to the geofence.
event_type: ForecastedGeofenceEventTypeThe event type, forecasting three states for which a device can be in relative to a geofence:
ENTER: If a device is outside of a geofence, but would breach the fence if the device is moving at its current speed within time horizon window.
EXIT: If a device is inside of a geofence, but would breach the fence if the device is moving at its current speed within time horizon window.
IDLE: If a device is inside of a geofence, and the device is not moving.
forecasted_breach_time: Option<DateTime>The forecasted time the device will breach the geofence in ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ
geofence_properties: Option<HashMap<String, String>>The geofence properties.
Implementations
Sourceimpl ForecastedEvent
impl ForecastedEvent
Sourcepub fn geofence_id(&self) -> &str
pub fn geofence_id(&self) -> &str
The geofence identifier pertaining to the forecasted event.
Sourcepub fn is_device_in_geofence(&self) -> bool
pub fn is_device_in_geofence(&self) -> bool
Indicates if the device is located within the geofence.
Sourcepub fn nearest_distance(&self) -> f64
pub fn nearest_distance(&self) -> f64
The closest distance from the device's position to the geofence.
Sourcepub fn event_type(&self) -> &ForecastedGeofenceEventType
pub fn event_type(&self) -> &ForecastedGeofenceEventType
The event type, forecasting three states for which a device can be in relative to a geofence:
ENTER: If a device is outside of a geofence, but would breach the fence if the device is moving at its current speed within time horizon window.
EXIT: If a device is inside of a geofence, but would breach the fence if the device is moving at its current speed within time horizon window.
IDLE: If a device is inside of a geofence, and the device is not moving.
Sourcepub fn forecasted_breach_time(&self) -> Option<&DateTime>
pub fn forecasted_breach_time(&self) -> Option<&DateTime>
The forecasted time the device will breach the geofence in ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ
Sourceimpl ForecastedEvent
impl ForecastedEvent
Sourcepub fn builder() -> ForecastedEventBuilder
pub fn builder() -> ForecastedEventBuilder
Creates a new builder-style object to manufacture ForecastedEvent.