#[non_exhaustive]pub struct SearchForPositionResult {
pub place: Option<Place>,
pub distance: f64,
pub place_id: Option<String>,
}Expand description
Contains a search result from a position search query that is run on a place index resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.place: Option<Place>Details about the search result, such as its address and position.
distance: f64The distance in meters of a great-circle arc between the query position and the result.
A great-circle arc is the shortest path on a sphere, in this case the Earth. This returns the shortest distance between two locations.
place_id: Option<String>The unique identifier of the place. You can use this with the GetPlace operation to find the place again later.
For SearchPlaceIndexForPosition operations, the PlaceId is returned only by place indexes that use HERE or Grab as a data provider.
Implementations
Sourceimpl SearchForPositionResult
impl SearchForPositionResult
Sourcepub fn place(&self) -> Option<&Place>
pub fn place(&self) -> Option<&Place>
Details about the search result, such as its address and position.
Sourceimpl SearchForPositionResult
impl SearchForPositionResult
Sourcepub fn builder() -> SearchForPositionResultBuilder
pub fn builder() -> SearchForPositionResultBuilder
Creates a new builder-style object to manufacture SearchForPositionResult.