#[non_exhaustive]pub struct SearchForTextResult {
pub place: Option<Place>,
pub distance: Option<f64>,
pub relevance: Option<f64>,
pub place_id: Option<String>,
}Expand description
Contains a search result from a text search query that is run on a place index resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.place: Option<Place>Details about the search result, such as its address and position.
distance: Option<f64>The distance in meters of a great-circle arc between the bias position specified and the result. Distance will be returned only if a bias position was specified in the query.
A great-circle arc is the shortest path on a sphere, in this case the Earth. This returns the shortest distance between two locations.
relevance: Option<f64>The relative confidence in the match for a result among the results returned. For example, if more fields for an address match (including house number, street, city, country/region, and postal code), the relevance score is closer to 1.
Returned only when the partner selected is Esri or Grab.
place_id: Option<String>The unique identifier of the place. You can use this with the GetPlace operation to find the place again later.
For SearchPlaceIndexForText operations, the PlaceId is returned only by place indexes that use HERE or Grab as a data provider.
Implementations
Sourceimpl SearchForTextResult
impl SearchForTextResult
Sourcepub fn place(&self) -> Option<&Place>
pub fn place(&self) -> Option<&Place>
Details about the search result, such as its address and position.
Sourcepub fn distance(&self) -> Option<f64>
pub fn distance(&self) -> Option<f64>
The distance in meters of a great-circle arc between the bias position specified and the result. Distance will be returned only if a bias position was specified in the query.
A great-circle arc is the shortest path on a sphere, in this case the Earth. This returns the shortest distance between two locations.
Sourcepub fn relevance(&self) -> Option<f64>
pub fn relevance(&self) -> Option<f64>
The relative confidence in the match for a result among the results returned. For example, if more fields for an address match (including house number, street, city, country/region, and postal code), the relevance score is closer to 1.
Returned only when the partner selected is Esri or Grab.
Sourceimpl SearchForTextResult
impl SearchForTextResult
Sourcepub fn builder() -> SearchForTextResultBuilder
pub fn builder() -> SearchForTextResultBuilder
Creates a new builder-style object to manufacture SearchForTextResult.