#[non_exhaustive]pub struct SearchPlaceIndexForPositionSummary {
pub position: Vec<f64>,
pub max_results: Option<i32>,
pub data_source: String,
pub language: Option<String>,
}Expand description
A summary of the request sent by using SearchPlaceIndexForPosition.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.position: Vec<f64>The position specified in the request.
max_results: Option<i32>Contains the optional result count limit that is specified in the request.
Default value: 50
data_source: StringThe geospatial data provider attached to the place index resource specified in the request. Values can be one of the following:
-
Esri
-
Grab
-
Here
For more information about data providers, see Amazon Location Service data providers.
language: Option<String>The preferred language used to return results. Matches the language in the request. The value is a valid BCP 47 language tag, for example, en for English.
Implementations
Sourceimpl SearchPlaceIndexForPositionSummary
impl SearchPlaceIndexForPositionSummary
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
Contains the optional result count limit that is specified in the request.
Default value: 50
Sourcepub fn data_source(&self) -> &str
pub fn data_source(&self) -> &str
The geospatial data provider attached to the place index resource specified in the request. Values can be one of the following:
-
Esri
-
Grab
-
Here
For more information about data providers, see Amazon Location Service data providers.
Sourceimpl SearchPlaceIndexForPositionSummary
impl SearchPlaceIndexForPositionSummary
Sourcepub fn builder() -> SearchPlaceIndexForPositionSummaryBuilder
pub fn builder() -> SearchPlaceIndexForPositionSummaryBuilder
Creates a new builder-style object to manufacture SearchPlaceIndexForPositionSummary.